'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.calculateLogUrl = exports.calculateLogView = exports.fetchAllSuffix = exports.doubleUriEncode = exports.buildRunDetailsUrl = exports.buildClassicBuildUrl = exports.buildClassicInputUrl = exports.buildClassicConfigUrl = exports.rootPath = exports.buildClassicCreateJobUrl = exports.buildPipelineUrl = exports.buildOrganizationUrl = undefined;

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

exports.applyFetchAll = applyFetchAll;
exports.calculateFetchAll = calculateFetchAll;
exports.calculateNodeBaseUrl = calculateNodeBaseUrl;
exports.calculateStepsBaseUrl = calculateStepsBaseUrl;
exports.calculateRunLogURLObject = calculateRunLogURLObject;
exports.paginateUrl = paginateUrl;
exports.endSlash = endSlash;
exports.getRestUrl = getRestUrl;
exports.buildUrl = buildUrl;
exports.relativeUrl = relativeUrl;
exports.toClassicJobPage = toClassicJobPage;

var _config = require('../config');

var _config2 = _interopRequireDefault(_config);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Gives classic jenkins job path prefix.
 * For organization group '/folder1/org1', job prefix is: /job/folder1/job/org1
 * For root organization group '/', there is no prefix: ''.
 * @param organizationGroup organization group
 * @returns {string}
 */
function jobPrefixPath(organizationGroup) {
    if (organizationGroup && organizationGroup !== '/') {
        return '' + organizationGroup.split('/').join('/job/');
    }
    return '';
}

/**
 * Build a root-relative URL to the organization's pipeline list screen.
 * @param organization
 */
var buildOrganizationUrl = exports.buildOrganizationUrl = function buildOrganizationUrl(organization) {
    return '/organizations/' + encodeURIComponent(organization);
};

/**
 * Build a root-relative URL to the pipeline details screen.
 * @param organization
 * @param fullName
 * @param tabName
 * @returns {string}
 */
var buildPipelineUrl = exports.buildPipelineUrl = function buildPipelineUrl(organization, fullName, tabName) {
    var baseUrl = '/organizations/' + encodeURIComponent(organization) + '/' + ('' + encodeURIComponent(fullName));

    return tabName ? baseUrl + '/' + tabName : baseUrl;
};
var buildClassicCreateJobUrl = exports.buildClassicCreateJobUrl = function buildClassicCreateJobUrl() {
    var jenkinsUrl = _config2.default.getJenkinsRootURL();
    return '' + jenkinsUrl + jobPrefixPath(_config2.default.getOrganizationGroup()) + '/newJob';
};
var rootPath = exports.rootPath = function rootPath(name) {
    var jenkinsUrl = _config2.default.getJenkinsRootURL();
    return '' + jenkinsUrl + jobPrefixPath(_config2.default.getOrganizationGroup()) + '/job/' + name.split('/').join('/job/') + '/';
};

var buildClassicConfigUrl = exports.buildClassicConfigUrl = function buildClassicConfigUrl(pipeline) {
    if (pipeline && pipeline.fullName) {
        return rootPath(pipeline.fullName) + 'configure';
    }
    return null;
};

var buildClassicInputUrl = exports.buildClassicInputUrl = function buildClassicInputUrl(pipeline, branch, runNumber) {
    if (pipeline && pipeline.fullName) {
        if (pipeline.branchNames) {
            return rootPath(pipeline.fullName) + 'job/' + encodeURIComponent(branch) + '/' + encodeURIComponent(runNumber) + '/input';
        } else {
            return '' + rootPath(pipeline.fullName) + encodeURIComponent(runNumber) + '/input';
        }
    }
    return null;
};

// http://localhost:8080/jenkins/job/scherler/job/Jenkins-40617-params/build?delay=0sec
var buildClassicBuildUrl = exports.buildClassicBuildUrl = function buildClassicBuildUrl(pipeline) {
    if (pipeline && pipeline.fullName) {
        return rootPath(pipeline.fullName) + 'build?delay=0sec';
    }
    return null;
};

/**
 * Build a root-relative URL to the run details screen.
 * @param organization
 * @param pipeline
 * @param branch
 * @param runId
 * @param tabName
 *
 * FIXME-JM: Unify this with buildRunDetailsUrl in blueocean-core-js/src/js/UrlBuilder.js - this is madness.
 */
var buildRunDetailsUrl = exports.buildRunDetailsUrl = function buildRunDetailsUrl(organization, pipeline, branch, runId, tabName) {
    var baseUrl = '/organizations/' + encodeURIComponent(organization) + '/' + (encodeURIComponent(pipeline) + '/detail/') + (encodeURIComponent(branch) + '/' + encodeURIComponent(runId));
    return tabName ? baseUrl + '/' + tabName : baseUrl;
};

/**
 * Double encode name, feature/test#1 is encoded as feature%252Ftest%25231
 */
var doubleUriEncode = exports.doubleUriEncode = function doubleUriEncode(input) {
    return encodeURIComponent(encodeURIComponent(input));
};

// general fetchAllTrigger
var fetchAllSuffix = exports.fetchAllSuffix = '?start=0';

// Add fetchAllSuffix in case it is needed
function applyFetchAll(config, url) {
    // if we pass fetchAll means we want the full log -> start=0 will trigger that on the server
    if (config.fetchAll && !url.includes(fetchAllSuffix)) {
        return '' + url + fetchAllSuffix;
    }
    return url;
}

// using the hook 'location.search'.includes('start=0') to trigger fetchAll
function calculateFetchAll(props) {
    var search = props.location.search;


    if (search) {
        var stepReg = /start=([0-9]{1,})/;
        var match = stepReg.exec(search);
        if (match && match[1] && Number(match[1]) === 0) {
            return true;
        }
    }
    return false;
}

// using the hook 'location.search'.includes('view=0') to trigger the logConsole view instead of steps
var calculateLogView = exports.calculateLogView = function calculateLogView(props) {
    var search = props.location.search;


    if (search) {
        var viewReg = /view=([0-9]{1,})/;
        var match = viewReg.exec(search);
        if (match && match[1] && Number(match[1]) === 0) {
            return true;
        }
    }
    return false;
};
/*
 * helper to calculate log url. When we have a node we get create a special url, otherwise we use the url passed to us
 * @param config { nodesBaseUrl, node, url}
 */
var calculateLogUrl = exports.calculateLogUrl = function calculateLogUrl(config) {
    var returnUrl = config.url;
    if (config.node) {
        var nodesBaseUrl = config.nodesBaseUrl,
            node = config.node;

        returnUrl = nodesBaseUrl + '/' + node.id + '/log/';
    }
    return applyFetchAll(config, returnUrl);
};

/*
 * helper to calculate node(flowNodes) url.
 * If we have multibranch we generate a slightly different url
 * @param config { name, runId, branch, _appURLBase, isMultiBranch}
 */
function calculateNodeBaseUrl(config) {
    var name = config.name,
        runId = config.runId,
        branch = config.branch,
        _appURLBase = config._appURLBase,
        isMultiBranch = config.isMultiBranch,
        organization = config.organization;

    var baseUrl = _appURLBase + '/rest/organizations/' + encodeURIComponent(organization) + '/' + ('pipelines/' + name);
    if (isMultiBranch) {
        return baseUrl + '/branches/' + doubleUriEncode(branch) + '/runs/' + runId + '/nodes/';
    }
    return baseUrl + '/runs/' + runId + '/nodes/';
}

/*
 * helper to calculate steps(flowNodes) url.
 * If we have multibranch we generate a slightly different url
 * and if there are node in we request the steps for this node
 * @param config { name, runId, branch, _appURLBase, isMultiBranch, node}
 */
function calculateStepsBaseUrl(config) {
    var name = config.name,
        runId = config.runId,
        branch = config.branch,
        _appURLBase = config._appURLBase,
        isMultiBranch = config.isMultiBranch,
        node = config.node,
        organization = config.organization;

    var baseUrl = _appURLBase + '/rest/organizations/' + encodeURIComponent(organization) + '/' + ('pipelines/' + name);
    if (isMultiBranch) {
        baseUrl = baseUrl + '/branches/' + doubleUriEncode(branch);
    }
    if (node && node !== null) {
        return baseUrl + '/runs/' + runId + '/nodes/' + node + '/steps/';
    }
    return baseUrl + '/runs/' + runId + '/steps/';
}
/*
 * helper to calculate general log url, includes filename.
 * If we have multibranch we generate a slightly different url
 * @param config { name, runId, branch, _appURLBase, isMultiBranch}
 */
function calculateRunLogURLObject(config) {
    var name = config.name,
        runId = config.runId,
        branch = config.branch,
        _appURLBase = config._appURLBase,
        isMultiBranch = config.isMultiBranch,
        organization = config.organization;

    var baseUrl = _appURLBase + '/rest/organizations/' + encodeURIComponent(organization) + ('/pipelines/' + name);
    var url = void 0;
    var fileName = void 0;
    if (isMultiBranch) {
        url = baseUrl + '/branches/' + doubleUriEncode(branch) + '/runs/' + runId + '/log/';
        fileName = branch + '-' + runId + '.txt';
    } else {
        url = baseUrl + '/runs/' + runId + '/log/';
        fileName = runId + '.txt';
    }
    url = applyFetchAll(config, url);
    return {
        url: url,
        fileName: fileName
    };
}

/**
 * Provide a pagination function for the generic
 * blueocean pagination
 */
function paginateUrl(url) {
    var sep = url.indexOf('?') >= 0 ? '&' : '?';
    return function (start, limit) {
        return '' + url + sep + 'start=' + start + '&limit=' + limit;
    };
}

/**
 * Returns a new string which ends with a slash, or the
 * original if it already does
 */
function endSlash(str) {
    if (!str) {
        return str;
    }
    if (str.charAt(str.length - 1) !== '/') {
        return str + '/';
    }
    return str;
}

/**
 * Examines the provided object for:
 * organization, pipeline, branch, runId
 * and builds a path to the thing as best it can...
 */
function getRestUrl(_ref) {
    var organization = _ref.organization,
        pipeline = _ref.pipeline,
        branch = _ref.branch,
        runId = _ref.runId;

    var pipelineName = (typeof pipeline === 'undefined' ? 'undefined' : _typeof(pipeline)) === 'object' ? pipeline.fullName : pipeline;
    var organizationName = organization || ((typeof pipeline === 'undefined' ? 'undefined' : _typeof(pipeline)) === 'object' ? pipeline.organization : '');
    var jenkinsUrl = _config2.default.getJenkinsRootURL();
    var url = jenkinsUrl + '/blue/rest/organizations/' + encodeURIComponent(organizationName);
    if (pipelineName) {
        // pipelineName might include a folder path, don't encode it
        url += '/pipelines/' + pipelineName;
    }
    if (branch) {
        // JENKINS-37712 branch needs to be double-encoded for some reason
        url += '/branches/' + encodeURIComponent(encodeURIComponent(branch));
    }
    if (runId) {
        url += '/runs/' + encodeURIComponent(runId);
    }
    return endSlash(url);
}

/**
 * Constructs an escaped url based on the arguments, with forward slashes between them
 * e.g. buildURL('organizations', orgName, 'runs', runId) => organizations/my%20org/runs/34
 */
function buildUrl() {
    var url = '';

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
    }

    for (var i = 0; i < args.length; i++) {
        if (i > 0) {
            url += '/';
        }
        url += encodeURIComponent(args[i]);
    }
    return url;
}

/**
 * Returns a relative URL based on the current location
 */
function relativeUrl(location) {
    for (var _len2 = arguments.length, args = Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
        args[_key2 - 1] = arguments[_key2];
    }

    return endSlash(location.pathname) + buildUrl.apply(null, args);
}

/**
 * Check is the current Blue ocean page a pipeline page and if so,
 * decode it to the corresponding classic Jenkins Job page.
 * @returns {string|undefined} The classic job page, or undefined if
 * it was unable to decode the page URL.
 */
function toClassicJobPage(pageUrl) {
    var isMultibranch = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;

    var pageUrlTokens = pageUrl.split('/').filter(function (token) {
        return typeof token === 'string' && token !== '';
    });

    // Remove all path elements up to and including the Jenkins
    // organization name.
    var token = pageUrlTokens.shift();
    while (token !== undefined && token !== 'organizations') {
        token = pageUrlTokens.shift();
    }
    var classicJobFullName = jobPrefixPath(_config2.default.getOrganizationGroup());
    if (pageUrlTokens.length > 1) {
        // The next token is the actual organization name e.g. "jenkins".
        // Remove that since we don't need it.
        pageUrlTokens.shift();

        // The next token is the "full" job name, URL encoded.
        var fullJobName = decodeURIComponent(pageUrlTokens.shift());
        var fullJobNameTokens = fullJobName.split('/');
        if (fullJobName !== 'pipelines' && pageUrlTokens.length > 0) {
            classicJobFullName = classicJobFullName + '/job/' + fullJobNameTokens.join('/job/');
        }
        if (pageUrlTokens.length > 1) {
            // The next token being "detail" indicates that we're looking
            // at a branch.
            if (pageUrlTokens.shift() === 'detail') {
                // is going to be something like one of:
                // - detail/[freestyleA/activity]
                // - detail/[freestyleA/2/pipeline]
                if (isMultibranch) {
                    var branchName = pageUrlTokens.shift(); // "freestyleA"
                    var classicJobBranch = classicJobFullName + '/job/' + branchName;

                    // And if there's more than one token left then we have
                    // the detail/freestyleA/[2/pipeline] variant. The next
                    // token is the runId
                    if (pageUrlTokens.length > 1) {
                        return classicJobBranch + '/' + pageUrlTokens.shift(); // "2"
                    }

                    return classicJobBranch;
                } else if (pageUrlTokens.length > 2) {
                    // And if there's more than two tokens left then we have
                    // the detail/[freestyleA/2/pipeline] variant.
                    // Next token is the branch name - not really a branch name !!
                    // Ignoring it.
                    pageUrlTokens.shift(); // "freestyleA"
                    // And the next token is the runId.
                    var runId = pageUrlTokens.shift(); // "2"
                    return classicJobFullName + '/' + runId;
                }
            }
        }
    }

    return classicJobFullName;
}
//# sourceMappingURL=UrlUtils.js.map
